ConfigSettings 
==============

ConfigSettings simplifies the loading and saving of application 
configurations. Configurations can be taken from ENVIRONMENT variables
or from config files. 

ConfigSettings goal is to be an extensible application settings 
module. 

Test
---

    make test

You can also test with a specific version of Python:

    make PYTHON_VERSION=2.7.11 test
